package de.intevation.flys.artifacts.model;

import java.util.ArrayList;
import java.util.List;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.DefaultFacet;

import de.intevation.flys.artifacts.MainValuesArtifact;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.jfree.FLYSAnnotation;
import de.intevation.flys.jfree.StickyAxisAnnotation;

/**
 * Facet to show Main Q Values.
 * TODO Join with W implementation.
 */
public class MainValuesQFacet
extends      DefaultFacet
implements   FacetTypes {

    /** Do we want MainValues at Gauge (not interpolated)? */
    protected boolean isAtGauge;

    /** Trivial Constructor. */
    public MainValuesQFacet(String name, String description, boolean atGauge) {
        this.description = description;
        this.name = name;
        this.index = 0;
        this.isAtGauge = atGauge;
    }


    /**
     * Returns the data this facet requires.
     *
     * @param artifact the owner artifact.
     * @param context  the CallContext (ignored).
     *
     * @return the data.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        MainValuesArtifact mvArtifact = (MainValuesArtifact) artifact;

        List<NamedDouble>      qs = mvArtifact.getMainValuesQ(isAtGauge);
        List<StickyAxisAnnotation> xy = new ArrayList<StickyAxisAnnotation>();

        for (NamedDouble q: qs) {
            xy.add(new StickyAxisAnnotation(
                q.getName(),
                (float) q.getValue(),
                StickyAxisAnnotation.SimpleAxis.X_AXIS));
        }

        return new FLYSAnnotation(description, xy);
    }


    /**
     * Create a deep copy of this Facet.
     * @return a deep copy.
     */
    @Override
    public MainValuesQFacet deepCopy() {
        MainValuesQFacet copy = new MainValuesQFacet(this.name,
            description, this.isAtGauge);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
